CellReel
========

|PyPI Version| |Tests Status| |Coverage Status| |Docs Status|


**CellReel** is a graphical user interface for performing fluorescence and
refractive index tomography of biological samples, particularly
if the acquired data must be aligned temporarily and spatially
post-measurement.


Documentation
-------------

The documentation, including the code reference and examples, is available at
`cellreel.readthedocs.io <https://cellreel.readthedocs.io/en/stable/>`__.


Installation
------------

::

    pip install cellreel


Testing
-------

::

    pip install -e .
    pip install pytest pytest-qt
    pytest tests


.. |PyPI Version| image:: https://img.shields.io/pypi/v/cellreel.svg
   :target: https://pypi.python.org/pypi/cellreel
.. |Tests Status| image:: https://img.shields.io/github/workflow/status/RI-Imaging/cellreel/Checks
   :target: https://github.com/RI-Imaging/cellreel/actions?query=workflow%3AChecks
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/RI-imaging/cellreel/master.svg
   :target: https://codecov.io/gh/RI-imaging/cellreel
.. |Docs Status| image:: https://readthedocs.org/projects/cellreel/badge/?version=latest
   :target: https://readthedocs.org/projects/cellreel/builds/

